@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2002 Jean-Baptiste Mardelle <bj@altern.org>
- * Copyright (C) 2008,2009,2010,2011 Rolf Eike Beer <kde@opensource.sf-tec.de>
+ * Copyright (C) 2008,2009,2010,2011,2012 Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 
 /***************************************************************************
@@ -183,7 +183,7 @@ void KGpgExternalActions::startFolderEncode()
 		delete over;
 	}
 
-	FolderCompressJob *trayinfo = new FolderCompressJob(m_keysmanager, droppedUrls.first(), encryptedFile, kgpgfoldertmp, selec, encryptOptions, encOptions);
+	FolderCompressJob *trayinfo = new FolderCompressJob(m_keysmanager, droppedUrls, encryptedFile, kgpgfoldertmp, selec, encryptOptions, encOptions, compressionScheme);
 	connect(trayinfo, SIGNAL(result(KJob*)), SLOT(slotFolderFinished(KJob*)));
 	KIO::getJobTracker()->registerJob(trayinfo);
 	trayinfo->start();
@@ -292,14 +292,14 @@ void KGpgExternalActions::decryptDroppedFile()
 
 void KGpgExternalActions::decryptFile()
 {
+	if (droppedUrls.isEmpty())
+		return;
+
 	while (!droppedUrls.first().isLocalFile()) {
 		showDroppedFile();
 		droppedUrls.pop_front();
 	}
 
-	if (droppedUrls.isEmpty())
-		return;
-
 	QString oldname(droppedUrls.first().fileName());
 	if (oldname.endsWith(QLatin1String(".gpg"), Qt::CaseInsensitive) ||
 			oldname.endsWith(QLatin1String(".asc"), Qt::CaseInsensitive) ||
